@@ -9,6 +9,7 @@ nn_budget = None
 nms_max_overlap = 1.0
 tracking = True
 dest_dir = os.path.expanduser('~') + os.path.sep + '.deepvision' + os.path.sep + 'object_detection' + os.path.sep + 'yolo' + os.path.sep + 'yolov3'
+colors = np.random.uniform(0, 255, size=(80, 3))
 
 # Deep SORT
 model_filename = 'mars-small128.pb'
@@ -24,8 +25,6 @@ tracker = Tracker(metric)
 
 def Track(boxes, classes, confidence, frame):
 
-    colors = np.random.uniform(0, 255, size=(len(classes), 3))
-
     for i, label in enumerate(classes):
 
         color = colors[classes.index(label)]
@@ -57,7 +56,6 @@ def Track(boxes, classes, confidence, frame):
         if not track.is_confirmed() or track.time_since_update > 1:
             continue
         bbox = track.to_tlbr()
-        # cv2.rectangle(frame, (int(bbox[i][0]), int(bbox[i][1])), (int(bbox[i][2]), int(bbox[i][3])), (255, 255, 255), 2)
         cv2.putText(frame, "ID: " + str(track.track_id), (int(bbox[0]), int(bbox[1])), 0,
                     0.5, (0, 255, 0), 2)
 
